# Project Documentation

This project uses MkDocs to build and serve its documentation.

#### Install the required dependencies from `./docs/requirements.txt`:

```bash
pip install -r ./docs/requirements.txt
```

#### Build and run the docs:
```bash
mkdocs serve
```

